//
// anyRemote
// a bluetooth remote for your PC.
//
// Copyright (C) 2009-2012 Mikhail Fedotov <anyremote@mail.ru>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef _PR_FRONTEND_H
#define _PR_FRONTEND_H


// Frontend support
gboolean frontendRoutine(gpointer data);
int   connectFrontEnd	(int portno);
void  sendToFrontEnd	(const char *buf);
void  disconnectFrontEnd(void);
int   readFromFrontEnd	(const char *buf, int size);

#endif
